summaryrefslogtreecommitdiffstatshomepage
path: root/src/mame/machine/harddriv.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mame/machine/harddriv.cpp')
-rw-r--r--src/mame/machine/harddriv.cpp15
1 files changed, 3 insertions, 12 deletions
diff --git a/src/mame/machine/harddriv.cpp b/src/mame/machine/harddriv.cpp
index a6199aa9679..529aebac5ce 100644
--- a/src/mame/machine/harddriv.cpp
+++ b/src/mame/machine/harddriv.cpp
@@ -221,7 +221,7 @@ READ16_MEMBER( harddriv_state::hd68k_port0_r )
int temp = (m_sw1.read_safe(0xff) << 8) | m_in0->read();
if (get_hblank(scr)) temp ^= 0x0002;
- temp ^= 0x0018; /* both EOCs always high for now */
+ temp ^= 0x0008; /* 12-bit EOC always high for now */
return temp;
}
@@ -285,12 +285,6 @@ READ16_MEMBER( harddriv_state::hdc68k_wheel_r )
}
-READ16_MEMBER( harddriv_state::hd68k_adc8_r )
-{
- return m_adc8_data;
-}
-
-
READ16_MEMBER( harddriv_state::hd68k_adc12_r )
{
return m_adc12_byte ? ((m_adc12_data >> 8) & 0x0f) : (m_adc12_data & 0xff);
@@ -317,11 +311,8 @@ WRITE16_MEMBER( harddriv_state::hd68k_adc_control_w )
COMBINE_DATA(&m_adc_control);
/* handle a write to the 8-bit ADC address select */
- if (m_adc_control & 0x08)
- {
- m_adc8_select = m_adc_control & 0x07;
- m_adc8_data = m_8badc[m_adc8_select].read_safe(0xffff);
- }
+ m_adc8->address_w(space, 0, m_adc_control & 0x07);
+ m_adc8->start_w(BIT(m_adc_control, 3));
/* handle a write to the 12-bit ADC address select */
if (m_adc_control & 0x40)